@@ -16,6 +16,7 @@ with y = 2*x).
 
 Examples:
 
+  import uncertainties
   from uncertainties import ufloat
   from uncertainties.umath import *  # sin(), etc.
 
@@ -39,7 +40,7 @@ Examples:
 
   # Correlations:
   u = ufloat((1, 0.05), "u variable")  # Tag
-  v = ufloat((10, 0.1),  "v variable")
+  v = ufloat((10, 0.1), "v variable")
   sum_value = u+v
   
   u.set_std_dev(0.1)  # Standard deviations can be updated on the fly
@@ -108,41 +109,41 @@ as input for the definition of correlated quantities (correlated_values()
 function--defined only if the NumPy module is available).
 
 - Mathematical expressions involving numbers with uncertainties
-(Variable objects) generally return AffineScalarFunc objects, which
-also print as a value with uncertainty.  Their most useful attributes
-and methods are described in the documentation for AffineScalarFunc.
-Note that Variable objects are also AffineScalarFunc objects: testing
-whether a value carries an uncertainty handled by this module should
-be done with insinstance(my_value, AffineScalarFunc).
+generally return AffineScalarFunc objects, which also print as a value
+with uncertainty.  Their most useful attributes and methods are
+described in the documentation for AffineScalarFunc.  Note that
+Variable objects are also AffineScalarFunc objects: testing whether a
+value carries an uncertainty handled by this module should be done
+with insinstance(my_value, AffineScalarFunc).
 
-- Mathematically, numbers with uncertainties are defined as
-probability distributions, which are described here by two numbers: a
-nominal value and an uncertainty.  Thus, both variables
+- Mathematically, numbers with uncertainties are, in this package,
+probability distributions.  These probabilities are reduced to two
+numbers: a nominal value and an uncertainty.  Thus, both variables
 (Variable objects) and the result of mathematical operations
 (AffineScalarFunc objects) contain these two values (respectively in
 their nominal_value attribute and through their std_dev() method).
 
-Uncertainties are simply defined here as the standard deviation of the
-underlying probability distribution.
+The uncertainty of a number with uncertainty is simply defined in
+this package as the standard deviation of the underlying probability
+distribution.
 
-Nominal values are normally contained well inside the region of
-highest probability of their underlying distribution.  The nominal
-value of an expression is the expression evaluated at the nominal
-values of its variables.
-
-Good choices of nominal values for random variables (ufloat objects)
-are thus their median, the location of highest probability, or their
-average value: the nominal value of expressions should then be well
-inside their region of highest probability.
+The numbers with uncertainties manipulated by this package are assumed
+to have a probability distribution mostly contained around their
+nominal value, in an interval of about the size of their standard
+deviation.  This should cover most practical cases.  A good choice of
+nominal value for a number with uncertainty is thus the median of its
+probability distribution, the location of highest probability, or the
+average value.
 
 - When manipulating ensembles of numbers, some of which contain
-uncertainties, it can be useful to access the nominal value of all
-numbers in a uniform manner:
+uncertainties, it can be useful to access the nominal value and
+uncertainty of all numbers in a uniform manner:
 
   x = ufloat("3+/-0.1")
   print nominal_value(x)  # Prints 3
   print std_dev(x)  # Prints 0.1
   print nominal_value(3)  # Prints 3: nominal_value works on floats
+  print std_dev(3)  # Prints 0: std_dev works on floats
 
 - Probability distributions (random variables and calculation results)
 are printed as:
@@ -165,24 +166,25 @@ distribution of their variables is the largest.  It is therefore
 important that uncertainties be small.  Mathematically, this means
 that the linear term of functions around the nominal values of their
 variables should be much larger than the remaining higher-order terms
-(over the region of significant probability).
+over the region of significant probability.
 
 For instance, sin(0+/-0.01) yields a meaningful standard deviation
-since it is quite linear over 0+/-0.01.  However, cos(0+/-0.01), which
-is parabolic around 0, yields an approximate standard deviation of 0,
-which might not be precise enough for all applications.
+since it is quite linear over 0+/-0.01.  However, cos(0+/-0.01) yields
+an approximate standard deviation of 0 (because the cosine is not well
+approximated by a line around 0), which might not be precise enough
+for all applications.
 
-- Logical operations (>, ==, etc.) on numbers with uncertainties have
-a pragmatic semantics, in this module: numbers with uncertainties can
-be used wherever Python numbers are used, most of the time with a
-result identical to the one that would be obtained with their nominal
-value only.  However, since the objects defined in this module
-represent probability distributions and not pure numbers, logical
-operations are defined in a specific way.
+- Comparison operations (>, ==, etc.) on numbers with uncertainties
+have a pragmatic semantics, in this package: numbers with
+uncertainties can be used wherever Python numbers are used, most of
+the time with a result identical to the one that would be obtained
+with their nominal value only.  However, since the objects defined in
+this module represent probability distributions and not pure numbers,
+comparison operator are interpreted in a specific way.
 
-The result of a logical operation ("==", ">", etc.) is defined so as
+The result of a comparison operation ("==", ">", etc.) is defined so as
 to be essentially consistent with the requirement that uncertainties
-be small: the value of a logical operation is True only if the
+be small: the value of a comparison operation is True only if the
 operation yields True for all infinitesimal variations of its random
 variables, except, possibly, for an infinitely small number of cases.
 
@@ -214,6 +216,7 @@ users, which helped improve this program.
 
 (c) 2009-2010 by Eric O. LEBIGOT (EOL) <eric.lebigot@normalesup.org>.
 Please send feature requests, bug reports, or feedback to this address.
+
 Please support future development by donating $5 or more through PayPal!
 
 This software is released under a dual license.  (1) The GNU General
@@ -235,7 +238,7 @@ import math
 from math import sqrt, log  # Optimization: no attribute look-up
 import copy
 
-__version__ = '1.5.4'
+__version__ = '1.5.4.3'
 # Numerical version:
 __version_info__ = tuple(int(num) for num in __version__.split('.'))
 
@@ -525,12 +528,12 @@ def wrap(f, derivatives_funcs=None):
             derivatives_wrt_args.append(derivative(*args_values)
                                         if arg.derivatives
                                         else 0)
-                                
 
         ########################################
         # Calculation of the derivative of f with respect to all the
         # variables (Variable) involved.
 
+        # Initial value (is updated below):
         derivatives_wrt_vars = dict((var, 0.) for var in variables)
 
         # The chain rule is used (we already have
@@ -538,8 +541,7 @@ def wrap(f, derivatives_funcs=None):
 
         for (func, f_derivative) in zip(aff_funcs, derivatives_wrt_args):
             for (var, func_derivative) in func.derivatives.iteritems():
-                derivatives_wrt_vars[var] += (f_derivative
-                                              * func_derivative)
+                derivatives_wrt_vars[var] += f_derivative * func_derivative
 
         # The function now returns an AffineScalarFunc object:
         return AffineScalarFunc(f_nominal_value, derivatives_wrt_vars)
@@ -711,11 +713,13 @@ class AffineScalarFunc(object):
 
         # Defines the value at the origin:
 
-        #! There is no coercion to a float, here, because
-        # AffineScalarFunc objects are also used for representing
-        # constants of any type (in which case derivatives is empty:
-        # there are no variables):
-        self._nominal_value = nominal_value
+        # Only float-like values are handled.  One reason is that it
+        # does not make sense for a scalar function to be affine to
+        # not yield float values.  Another reason is that it would not
+        # make sense to have a complex nominal value, here (it would
+        # not be handled correctly at all): converting to float should
+        # be possible.
+        self._nominal_value = float(nominal_value)
         self.derivatives = derivatives
 
     @property
