@@ -17,15 +17,19 @@ import uncertainties
 import uncertainties.umath as umath
 import test_uncertainties
 
+from uncertainties import __author__
+
 ###############################################################################
 # Unit tests
     
 def test_fixed_derivatives_math_funcs():
     """
-    Check of wrapped functions from the math module.
+    Comparison between function derivatives and numerical derivatives.
+
+    This comparison is useful for derivatives that are analytical.
     """
 
-    for name in umath.std_wrapped_math_funcs:
+    for name in umath.many_scalar_to_scalar_funcs:
         # print "Checking %s..." % name
         func = getattr(umath, name)
         # Numerical derivatives of func: the nominal value of func() results
@@ -34,6 +38,40 @@ def test_fixed_derivatives_math_funcs():
             lambda *args: func(*args).nominal_value)
         test_uncertainties._compare_derivatives(func, numerical_derivatives)
 
+    # Functions that are not in umath.many_scalar_to_scalar_funcs:
+
+    ##
+    # modf(): returns a tuple:
+    def frac_part_modf(x):
+        return umath.modf(x)[0]
+    def int_part_modf(x):
+        return umath.modf(x)[1]
+    
+    test_uncertainties._compare_derivatives(
+        frac_part_modf,
+        uncertainties.NumericalDerivatives(
+            lambda x: frac_part_modf(x).nominal_value))
+    test_uncertainties._compare_derivatives(
+        int_part_modf,
+        uncertainties.NumericalDerivatives(
+            lambda x: int_part_modf(x).nominal_value))
+    
+    ##
+    # frexp(): returns a tuple:
+    def mantissa_frexp(x):
+        return umath.frexp(x)[0]
+    def exponent_frexp(x):
+        return umath.frexp(x)[1]
+    
+    test_uncertainties._compare_derivatives(
+        mantissa_frexp,
+        uncertainties.NumericalDerivatives(
+            lambda x: mantissa_frexp(x).nominal_value))
+    test_uncertainties._compare_derivatives(
+        exponent_frexp,
+        uncertainties.NumericalDerivatives(
+            lambda x: exponent_frexp(x).nominal_value))
+
 def test_compound_expression():
     """
     Test equality between different formulas.
@@ -168,10 +206,13 @@ def test_math_module():
 
     if sys.version_info[:2] >= (2, 6):
     
-        # factorial must not be "damaged" by this module; in particular,
-        # as of Python 2.6, it does not accept non integral values, and
-        # must therefore not be differentiated:
-        assert umath.factorial(4) == 24
+        # factorial must not be "damaged" by this module; in
+        # particular, as of Python 2.6, it does not accept non
+        # integral values, and the user should not want to give
+        # uncertain (continuous) arguments to an equivalent of the
+        # math.factorial() function:
+        #
+        # assert umath.factorial(4) == 24
 
         # Boolean functions:
         assert not umath.isinf(x)
