@@ -120,13 +120,16 @@ def derivative(u, var):
 
 def wrap_array_func(func):
     """
-    Returns a version of the function func that works even when func
-    is given a NumPy array that contains numbers with uncertainties.
+    Returns a version of the function func() that works even when
+    func() is given a NumPy array that contains numbers with
+    uncertainties.
+
+    func() is supposed to return a NumPy array.
 
     This wrapper is similar to uncertainties.wrap(), except that it
     handles an array argument instead of float arguments.
     
-    func -- version that takes a single NumPy array.
+    func -- version that takes and returns a single NumPy array.
     """
 
     @uncertainties.set_doc("""\
@@ -416,10 +419,10 @@ def define_vectorized_funcs():
         func_name_translations[function_name]
         if function_name in func_name_translations
         else function_name
-        for function_name in umath.std_wrapped_math_funcs]
+        for function_name in umath.many_scalar_to_scalar_funcs]
         
     for (function_name, unumpy_name) in \
-        zip(umath.std_wrapped_math_funcs, new_func_names):
+        zip(umath.many_scalar_to_scalar_funcs, new_func_names):
 
         # ! The newly defined functions (uncertainties.unumpy.cos, etc.)
         # do not behave exactly like their NumPy equivalent (numpy.cos,
